# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from routerrpc import router_pb2 as routerrpc_dot_router__pb2


class RouterStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SendPayment = channel.unary_stream(
        '/routerrpc.Router/SendPayment',
        request_serializer=routerrpc_dot_router__pb2.SendPaymentRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.PaymentStatus.FromString,
        )
    self.TrackPayment = channel.unary_stream(
        '/routerrpc.Router/TrackPayment',
        request_serializer=routerrpc_dot_router__pb2.TrackPaymentRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.PaymentStatus.FromString,
        )
    self.EstimateRouteFee = channel.unary_unary(
        '/routerrpc.Router/EstimateRouteFee',
        request_serializer=routerrpc_dot_router__pb2.RouteFeeRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.RouteFeeResponse.FromString,
        )
    self.SendToRoute = channel.unary_unary(
        '/routerrpc.Router/SendToRoute',
        request_serializer=routerrpc_dot_router__pb2.SendToRouteRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.SendToRouteResponse.FromString,
        )
    self.ResetMissionControl = channel.unary_unary(
        '/routerrpc.Router/ResetMissionControl',
        request_serializer=routerrpc_dot_router__pb2.ResetMissionControlRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.ResetMissionControlResponse.FromString,
        )
    self.QueryMissionControl = channel.unary_unary(
        '/routerrpc.Router/QueryMissionControl',
        request_serializer=routerrpc_dot_router__pb2.QueryMissionControlRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.QueryMissionControlResponse.FromString,
        )
    self.BuildRoute = channel.unary_unary(
        '/routerrpc.Router/BuildRoute',
        request_serializer=routerrpc_dot_router__pb2.BuildRouteRequest.SerializeToString,
        response_deserializer=routerrpc_dot_router__pb2.BuildRouteResponse.FromString,
        )


class RouterServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def SendPayment(self, request, context):
    """*
    SendPayment attempts to route a payment described by the passed
    PaymentRequest to the final destination. The call returns a stream of
    payment status updates.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TrackPayment(self, request, context):
    """*
    TrackPayment returns an update stream for the payment identified by the
    payment hash.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EstimateRouteFee(self, request, context):
    """*
    EstimateRouteFee allows callers to obtain a lower bound w.r.t how much it
    may cost to send an HTLC to the target end destination.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendToRoute(self, request, context):
    """*
    SendToRoute attempts to make a payment via the specified route. This method
    differs from SendPayment in that it allows users to specify a full route
    manually. This can be used for things like rebalancing, and atomic swaps.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResetMissionControl(self, request, context):
    """*
    ResetMissionControl clears all mission control state and starts with a clean
    slate.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def QueryMissionControl(self, request, context):
    """*
    QueryMissionControl exposes the internal mission control state to callers.
    It is a development feature.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BuildRoute(self, request, context):
    """*
    BuildRoute builds a fully specified route based on a list of hop public
    keys. It retrieves the relevant channel policies from the graph in order to
    calculate the correct fees and time locks.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RouterServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SendPayment': grpc.unary_stream_rpc_method_handler(
          servicer.SendPayment,
          request_deserializer=routerrpc_dot_router__pb2.SendPaymentRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.PaymentStatus.SerializeToString,
      ),
      'TrackPayment': grpc.unary_stream_rpc_method_handler(
          servicer.TrackPayment,
          request_deserializer=routerrpc_dot_router__pb2.TrackPaymentRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.PaymentStatus.SerializeToString,
      ),
      'EstimateRouteFee': grpc.unary_unary_rpc_method_handler(
          servicer.EstimateRouteFee,
          request_deserializer=routerrpc_dot_router__pb2.RouteFeeRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.RouteFeeResponse.SerializeToString,
      ),
      'SendToRoute': grpc.unary_unary_rpc_method_handler(
          servicer.SendToRoute,
          request_deserializer=routerrpc_dot_router__pb2.SendToRouteRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.SendToRouteResponse.SerializeToString,
      ),
      'ResetMissionControl': grpc.unary_unary_rpc_method_handler(
          servicer.ResetMissionControl,
          request_deserializer=routerrpc_dot_router__pb2.ResetMissionControlRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.ResetMissionControlResponse.SerializeToString,
      ),
      'QueryMissionControl': grpc.unary_unary_rpc_method_handler(
          servicer.QueryMissionControl,
          request_deserializer=routerrpc_dot_router__pb2.QueryMissionControlRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.QueryMissionControlResponse.SerializeToString,
      ),
      'BuildRoute': grpc.unary_unary_rpc_method_handler(
          servicer.BuildRoute,
          request_deserializer=routerrpc_dot_router__pb2.BuildRouteRequest.FromString,
          response_serializer=routerrpc_dot_router__pb2.BuildRouteResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'routerrpc.Router', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: watchtowerrpc/watchtower.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='watchtowerrpc/watchtower.proto',
  package='watchtowerrpc',
  syntax='proto3',
  serialized_options=_b('Z2github.com/lncm/lnd-rpc/v0.8.0/lnrpc/watchtowerrpc'),
  serialized_pb=_b('\n\x1ewatchtowerrpc/watchtower.proto\x12\rwatchtowerrpc\"\x10\n\x0eGetInfoRequest\"[\n\x0fGetInfoResponse\x12\x16\n\x06pubkey\x18\x01 \x01(\x0cR\x06pubkey\x12\x1c\n\tlisteners\x18\x02 \x03(\tR\tlisteners\x12\x12\n\x04uris\x18\x03 \x03(\tR\x04uris2V\n\nWatchtower\x12H\n\x07GetInfo\x12\x1d.watchtowerrpc.GetInfoRequest\x1a\x1e.watchtowerrpc.GetInfoResponseB4Z2github.com/lncm/lnd-rpc/v0.8.0/lnrpc/watchtowerrpcb\x06proto3')
)




_GETINFOREQUEST = _descriptor.Descriptor(
  name='GetInfoRequest',
  full_name='watchtowerrpc.GetInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=65,
)


_GETINFORESPONSE = _descriptor.Descriptor(
  name='GetInfoResponse',
  full_name='watchtowerrpc.GetInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='watchtowerrpc.GetInfoResponse.pubkey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubkey', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listeners', full_name='watchtowerrpc.GetInfoResponse.listeners', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='listeners', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uris', full_name='watchtowerrpc.GetInfoResponse.uris', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uris', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=158,
)

DESCRIPTOR.message_types_by_name['GetInfoRequest'] = _GETINFOREQUEST
DESCRIPTOR.message_types_by_name['GetInfoResponse'] = _GETINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInfoRequest = _reflection.GeneratedProtocolMessageType('GetInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINFOREQUEST,
  __module__ = 'watchtowerrpc.watchtower_pb2'
  # @@protoc_insertion_point(class_scope:watchtowerrpc.GetInfoRequest)
  ))
_sym_db.RegisterMessage(GetInfoRequest)

GetInfoResponse = _reflection.GeneratedProtocolMessageType('GetInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETINFORESPONSE,
  __module__ = 'watchtowerrpc.watchtower_pb2'
  # @@protoc_insertion_point(class_scope:watchtowerrpc.GetInfoResponse)
  ))
_sym_db.RegisterMessage(GetInfoResponse)


DESCRIPTOR._options = None

_WATCHTOWER = _descriptor.ServiceDescriptor(
  name='Watchtower',
  full_name='watchtowerrpc.Watchtower',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=160,
  serialized_end=246,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInfo',
    full_name='watchtowerrpc.Watchtower.GetInfo',
    index=0,
    containing_service=None,
    input_type=_GETINFOREQUEST,
    output_type=_GETINFORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WATCHTOWER)

DESCRIPTOR.services_by_name['Watchtower'] = _WATCHTOWER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from chainrpc import chainnotifier_pb2 as chainrpc_dot_chainnotifier__pb2


class ChainNotifierStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.RegisterConfirmationsNtfn = channel.unary_stream(
        '/chainrpc.ChainNotifier/RegisterConfirmationsNtfn',
        request_serializer=chainrpc_dot_chainnotifier__pb2.ConfRequest.SerializeToString,
        response_deserializer=chainrpc_dot_chainnotifier__pb2.ConfEvent.FromString,
        )
    self.RegisterSpendNtfn = channel.unary_stream(
        '/chainrpc.ChainNotifier/RegisterSpendNtfn',
        request_serializer=chainrpc_dot_chainnotifier__pb2.SpendRequest.SerializeToString,
        response_deserializer=chainrpc_dot_chainnotifier__pb2.SpendEvent.FromString,
        )
    self.RegisterBlockEpochNtfn = channel.unary_stream(
        '/chainrpc.ChainNotifier/RegisterBlockEpochNtfn',
        request_serializer=chainrpc_dot_chainnotifier__pb2.BlockEpoch.SerializeToString,
        response_deserializer=chainrpc_dot_chainnotifier__pb2.BlockEpoch.FromString,
        )


class ChainNotifierServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def RegisterConfirmationsNtfn(self, request, context):
    """
    RegisterConfirmationsNtfn is a synchronous response-streaming RPC that
    registers an intent for a client to be notified once a confirmation request
    has reached its required number of confirmations on-chain.

    A client can specify whether the confirmation request should be for a
    particular transaction by its hash or for an output script by specifying a
    zero hash.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterSpendNtfn(self, request, context):
    """
    RegisterSpendNtfn is a synchronous response-streaming RPC that registers an
    intent for a client to be notification once a spend request has been spent
    by a transaction that has confirmed on-chain.

    A client can specify whether the spend request should be for a particular
    outpoint  or for an output script by specifying a zero outpoint.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterBlockEpochNtfn(self, request, context):
    """
    RegisterBlockEpochNtfn is a synchronous response-streaming RPC that
    registers an intent for a client to be notified of blocks in the chain. The
    stream will return a hash and height tuple of a block for each new/stale
    block in the chain. It is the client's responsibility to determine whether
    the tuple returned is for a new or stale block in the chain.

    A client can also request a historical backlog of blocks from a particular
    point. This allows clients to be idempotent by ensuring that they do not
    missing processing a single block within the chain.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ChainNotifierServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'RegisterConfirmationsNtfn': grpc.unary_stream_rpc_method_handler(
          servicer.RegisterConfirmationsNtfn,
          request_deserializer=chainrpc_dot_chainnotifier__pb2.ConfRequest.FromString,
          response_serializer=chainrpc_dot_chainnotifier__pb2.ConfEvent.SerializeToString,
      ),
      'RegisterSpendNtfn': grpc.unary_stream_rpc_method_handler(
          servicer.RegisterSpendNtfn,
          request_deserializer=chainrpc_dot_chainnotifier__pb2.SpendRequest.FromString,
          response_serializer=chainrpc_dot_chainnotifier__pb2.SpendEvent.SerializeToString,
      ),
      'RegisterBlockEpochNtfn': grpc.unary_stream_rpc_method_handler(
          servicer.RegisterBlockEpochNtfn,
          request_deserializer=chainrpc_dot_chainnotifier__pb2.BlockEpoch.FromString,
          response_serializer=chainrpc_dot_chainnotifier__pb2.BlockEpoch.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chainrpc.ChainNotifier', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: invoicesrpc/invoices.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from lnrpc import rpc_pb2 as lnrpc_dot_rpc__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='invoicesrpc/invoices.proto',
  package='invoicesrpc',
  syntax='proto3',
  serialized_options=_b('Z0github.com/lncm/lnd-rpc/v0.8.0/lnrpc/invoicesrpc'),
  serialized_pb=_b('\n\x1ainvoicesrpc/invoices.proto\x12\x0binvoicesrpc\x1a\x1cgoogle/api/annotations.proto\x1a\x0flnrpc/rpc.proto\"(\n\x10\x43\x61ncelInvoiceMsg\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\"\x13\n\x11\x43\x61ncelInvoiceResp\"\xaf\x02\n\x15\x41\x64\x64HoldInvoiceRequest\x12\x12\n\x04memo\x18\x01 \x01(\tR\x04memo\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\x12\x14\n\x05value\x18\x03 \x01(\x03R\x05value\x12*\n\x10\x64\x65scription_hash\x18\x04 \x01(\x0cR\x10\x64\x65scription_hash\x12\x16\n\x06\x65xpiry\x18\x05 \x01(\x03R\x06\x65xpiry\x12$\n\rfallback_addr\x18\x06 \x01(\tR\rfallback_addr\x12 \n\x0b\x63ltv_expiry\x18\x07 \x01(\x04R\x0b\x63ltv_expiry\x12\x32\n\x0broute_hints\x18\x08 \x03(\x0b\x32\x10.lnrpc.RouteHintR\x0broute_hints\x12\x18\n\x07private\x18\t \x01(\x08R\x07private\">\n\x12\x41\x64\x64HoldInvoiceResp\x12(\n\x0fpayment_request\x18\x01 \x01(\tR\x0fpayment_request\"$\n\x10SettleInvoiceMsg\x12\x10\n\x08preimage\x18\x01 \x01(\x0c\"\x13\n\x11SettleInvoiceResp\"=\n\x1dSubscribeSingleInvoiceRequest\x12\x16\n\x06r_hash\x18\x02 \x01(\x0cR\x06r_hashJ\x04\x08\x01\x10\x02\x32\xd9\x02\n\x08Invoices\x12V\n\x16SubscribeSingleInvoice\x12*.invoicesrpc.SubscribeSingleInvoiceRequest\x1a\x0e.lnrpc.Invoice0\x01\x12N\n\rCancelInvoice\x12\x1d.invoicesrpc.CancelInvoiceMsg\x1a\x1e.invoicesrpc.CancelInvoiceResp\x12U\n\x0e\x41\x64\x64HoldInvoice\x12\".invoicesrpc.AddHoldInvoiceRequest\x1a\x1f.invoicesrpc.AddHoldInvoiceResp\x12N\n\rSettleInvoice\x12\x1d.invoicesrpc.SettleInvoiceMsg\x1a\x1e.invoicesrpc.SettleInvoiceRespB2Z0github.com/lncm/lnd-rpc/v0.8.0/lnrpc/invoicesrpcb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,lnrpc_dot_rpc__pb2.DESCRIPTOR,])




_CANCELINVOICEMSG = _descriptor.Descriptor(
  name='CancelInvoiceMsg',
  full_name='invoicesrpc.CancelInvoiceMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='invoicesrpc.CancelInvoiceMsg.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=130,
)


_CANCELINVOICERESP = _descriptor.Descriptor(
  name='CancelInvoiceResp',
  full_name='invoicesrpc.CancelInvoiceResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=151,
)


_ADDHOLDINVOICEREQUEST = _descriptor.Descriptor(
  name='AddHoldInvoiceRequest',
  full_name='invoicesrpc.AddHoldInvoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memo', full_name='invoicesrpc.AddHoldInvoiceRequest.memo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='memo', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='invoicesrpc.AddHoldInvoiceRequest.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hash', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='invoicesrpc.AddHoldInvoiceRequest.value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_hash', full_name='invoicesrpc.AddHoldInvoiceRequest.description_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='description_hash', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='invoicesrpc.AddHoldInvoiceRequest.expiry', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expiry', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_addr', full_name='invoicesrpc.AddHoldInvoiceRequest.fallback_addr', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fallback_addr', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_expiry', full_name='invoicesrpc.AddHoldInvoiceRequest.cltv_expiry', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cltv_expiry', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route_hints', full_name='invoicesrpc.AddHoldInvoiceRequest.route_hints', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='route_hints', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private', full_name='invoicesrpc.AddHoldInvoiceRequest.private', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='private', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=457,
)


_ADDHOLDINVOICERESP = _descriptor.Descriptor(
  name='AddHoldInvoiceResp',
  full_name='invoicesrpc.AddHoldInvoiceResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='invoicesrpc.AddHoldInvoiceResp.payment_request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='payment_request', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=521,
)


_SETTLEINVOICEMSG = _descriptor.Descriptor(
  name='SettleInvoiceMsg',
  full_name='invoicesrpc.SettleInvoiceMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preimage', full_name='invoicesrpc.SettleInvoiceMsg.preimage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=523,
  serialized_end=559,
)


_SETTLEINVOICERESP = _descriptor.Descriptor(
  name='SettleInvoiceResp',
  full_name='invoicesrpc.SettleInvoiceResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=580,
)


_SUBSCRIBESINGLEINVOICEREQUEST = _descriptor.Descriptor(
  name='SubscribeSingleInvoiceRequest',
  full_name='invoicesrpc.SubscribeSingleInvoiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r_hash', full_name='invoicesrpc.SubscribeSingleInvoiceRequest.r_hash', index=0,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='r_hash', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=643,
)

_ADDHOLDINVOICEREQUEST.fields_by_name['route_hints'].message_type = lnrpc_dot_rpc__pb2._ROUTEHINT
DESCRIPTOR.message_types_by_name['CancelInvoiceMsg'] = _CANCELINVOICEMSG
DESCRIPTOR.message_types_by_name['CancelInvoiceResp'] = _CANCELINVOICERESP
DESCRIPTOR.message_types_by_name['AddHoldInvoiceRequest'] = _ADDHOLDINVOICEREQUEST
DESCRIPTOR.message_types_by_name['AddHoldInvoiceResp'] = _ADDHOLDINVOICERESP
DESCRIPTOR.message_types_by_name['SettleInvoiceMsg'] = _SETTLEINVOICEMSG
DESCRIPTOR.message_types_by_name['SettleInvoiceResp'] = _SETTLEINVOICERESP
DESCRIPTOR.message_types_by_name['SubscribeSingleInvoiceRequest'] = _SUBSCRIBESINGLEINVOICEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CancelInvoiceMsg = _reflection.GeneratedProtocolMessageType('CancelInvoiceMsg', (_message.Message,), dict(
  DESCRIPTOR = _CANCELINVOICEMSG,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.CancelInvoiceMsg)
  ))
_sym_db.RegisterMessage(CancelInvoiceMsg)

CancelInvoiceResp = _reflection.GeneratedProtocolMessageType('CancelInvoiceResp', (_message.Message,), dict(
  DESCRIPTOR = _CANCELINVOICERESP,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.CancelInvoiceResp)
  ))
_sym_db.RegisterMessage(CancelInvoiceResp)

AddHoldInvoiceRequest = _reflection.GeneratedProtocolMessageType('AddHoldInvoiceRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLDINVOICEREQUEST,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.AddHoldInvoiceRequest)
  ))
_sym_db.RegisterMessage(AddHoldInvoiceRequest)

AddHoldInvoiceResp = _reflection.GeneratedProtocolMessageType('AddHoldInvoiceResp', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLDINVOICERESP,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.AddHoldInvoiceResp)
  ))
_sym_db.RegisterMessage(AddHoldInvoiceResp)

SettleInvoiceMsg = _reflection.GeneratedProtocolMessageType('SettleInvoiceMsg', (_message.Message,), dict(
  DESCRIPTOR = _SETTLEINVOICEMSG,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.SettleInvoiceMsg)
  ))
_sym_db.RegisterMessage(SettleInvoiceMsg)

SettleInvoiceResp = _reflection.GeneratedProtocolMessageType('SettleInvoiceResp', (_message.Message,), dict(
  DESCRIPTOR = _SETTLEINVOICERESP,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.SettleInvoiceResp)
  ))
_sym_db.RegisterMessage(SettleInvoiceResp)

SubscribeSingleInvoiceRequest = _reflection.GeneratedProtocolMessageType('SubscribeSingleInvoiceRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBESINGLEINVOICEREQUEST,
  __module__ = 'invoicesrpc.invoices_pb2'
  # @@protoc_insertion_point(class_scope:invoicesrpc.SubscribeSingleInvoiceRequest)
  ))
_sym_db.RegisterMessage(SubscribeSingleInvoiceRequest)


DESCRIPTOR._options = None

_INVOICES = _descriptor.ServiceDescriptor(
  name='Invoices',
  full_name='invoicesrpc.Invoices',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=646,
  serialized_end=991,
  methods=[
  _descriptor.MethodDescriptor(
    name='SubscribeSingleInvoice',
    full_name='invoicesrpc.Invoices.SubscribeSingleInvoice',
    index=0,
    containing_service=None,
    input_type=_SUBSCRIBESINGLEINVOICEREQUEST,
    output_type=lnrpc_dot_rpc__pb2._INVOICE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CancelInvoice',
    full_name='invoicesrpc.Invoices.CancelInvoice',
    index=1,
    containing_service=None,
    input_type=_CANCELINVOICEMSG,
    output_type=_CANCELINVOICERESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddHoldInvoice',
    full_name='invoicesrpc.Invoices.AddHoldInvoice',
    index=2,
    containing_service=None,
    input_type=_ADDHOLDINVOICEREQUEST,
    output_type=_ADDHOLDINVOICERESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SettleInvoice',
    full_name='invoicesrpc.Invoices.SettleInvoice',
    index=3,
    containing_service=None,
    input_type=_SETTLEINVOICEMSG,
    output_type=_SETTLEINVOICERESP,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INVOICES)

DESCRIPTOR.services_by_name['Invoices'] = _INVOICES

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: walletrpc/walletkit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from lnrpc import rpc_pb2 as lnrpc_dot_rpc__pb2
from signrpc import signer_pb2 as signrpc_dot_signer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='walletrpc/walletkit.proto',
  package='walletrpc',
  syntax='proto3',
  serialized_options=_b('Z.github.com/lncm/lnd-rpc/v0.8.0/lnrpc/walletrpc'),
  serialized_pb=_b('\n\x19walletrpc/walletkit.proto\x12\twalletrpc\x1a\x0flnrpc/rpc.proto\x1a\x14signrpc/signer.proto\"6\n\x06KeyReq\x12\x18\n\x10key_finger_print\x18\x01 \x01(\x05\x12\x12\n\nkey_family\x18\x02 \x01(\x05\"\r\n\x0b\x41\x64\x64rRequest\"\x1c\n\x0c\x41\x64\x64rResponse\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\"\x1d\n\x0bTransaction\x12\x0e\n\x06tx_hex\x18\x01 \x01(\x0c\"(\n\x0fPublishResponse\x12\x15\n\rpublish_error\x18\x01 \x01(\t\"I\n\x12SendOutputsRequest\x12\x12\n\nsat_per_kw\x18\x01 \x01(\x03\x12\x1f\n\x07outputs\x18\x02 \x03(\x0b\x32\x0e.signrpc.TxOut\"%\n\x13SendOutputsResponse\x12\x0e\n\x06raw_tx\x18\x01 \x01(\x0c\")\n\x12\x45stimateFeeRequest\x12\x13\n\x0b\x63onf_target\x18\x01 \x01(\x05\")\n\x13\x45stimateFeeResponse\x12\x12\n\nsat_per_kw\x18\x01 \x01(\x03\"\xa1\x02\n\x0cPendingSweep\x12+\n\x08outpoint\x18\x01 \x01(\x0b\x32\x0f.lnrpc.OutPointR\x08outpoint\x12:\n\x0cwitness_type\x18\x02 \x01(\x0e\x32\x16.walletrpc.WitnessTypeR\x0cwitness_type\x12\x1e\n\namount_sat\x18\x03 \x01(\rR\namount_sat\x12\"\n\x0csat_per_byte\x18\x04 \x01(\rR\x0csat_per_byte\x12.\n\x12\x62roadcast_attempts\x18\x05 \x01(\rR\x12\x62roadcast_attempts\x12\x34\n\x15next_broadcast_height\x18\x06 \x01(\rR\x15next_broadcast_height\"\x16\n\x14PendingSweepsRequest\"X\n\x15PendingSweepsResponse\x12?\n\x0epending_sweeps\x18\x01 \x03(\x0b\x32\x17.walletrpc.PendingSweepR\x0epending_sweeps\"\x83\x01\n\x0e\x42umpFeeRequest\x12+\n\x08outpoint\x18\x01 \x01(\x0b\x32\x0f.lnrpc.OutPointR\x08outpoint\x12 \n\x0btarget_conf\x18\x02 \x01(\rR\x0btarget_conf\x12\"\n\x0csat_per_byte\x18\x03 \x01(\rR\x0csat_per_byte\"\x11\n\x0f\x42umpFeeResponse*\x82\x03\n\x0bWitnessType\x12\x13\n\x0fUNKNOWN_WITNESS\x10\x00\x12\x18\n\x14\x43OMMITMENT_TIME_LOCK\x10\x01\x12\x17\n\x13\x43OMMITMENT_NO_DELAY\x10\x02\x12\x15\n\x11\x43OMMITMENT_REVOKE\x10\x03\x12\x17\n\x13HTLC_OFFERED_REVOKE\x10\x04\x12\x18\n\x14HTLC_ACCEPTED_REVOKE\x10\x05\x12%\n!HTLC_OFFERED_TIMEOUT_SECOND_LEVEL\x10\x06\x12&\n\"HTLC_ACCEPTED_SUCCESS_SECOND_LEVEL\x10\x07\x12\x1f\n\x1bHTLC_OFFERED_REMOTE_TIMEOUT\x10\x08\x12 \n\x1cHTLC_ACCEPTED_REMOTE_SUCCESS\x10\t\x12\x1c\n\x18HTLC_SECOND_LEVEL_REVOKE\x10\n\x12\x14\n\x10WITNESS_KEY_HASH\x10\x0b\x12\x1b\n\x17NESTED_WITNESS_KEY_HASH\x10\x0c\x32\xba\x04\n\tWalletKit\x12:\n\rDeriveNextKey\x12\x11.walletrpc.KeyReq\x1a\x16.signrpc.KeyDescriptor\x12\x38\n\tDeriveKey\x12\x13.signrpc.KeyLocator\x1a\x16.signrpc.KeyDescriptor\x12;\n\x08NextAddr\x12\x16.walletrpc.AddrRequest\x1a\x17.walletrpc.AddrResponse\x12H\n\x12PublishTransaction\x12\x16.walletrpc.Transaction\x1a\x1a.walletrpc.PublishResponse\x12L\n\x0bSendOutputs\x12\x1d.walletrpc.SendOutputsRequest\x1a\x1e.walletrpc.SendOutputsResponse\x12L\n\x0b\x45stimateFee\x12\x1d.walletrpc.EstimateFeeRequest\x1a\x1e.walletrpc.EstimateFeeResponse\x12R\n\rPendingSweeps\x12\x1f.walletrpc.PendingSweepsRequest\x1a .walletrpc.PendingSweepsResponse\x12@\n\x07\x42umpFee\x12\x19.walletrpc.BumpFeeRequest\x1a\x1a.walletrpc.BumpFeeResponseB0Z.github.com/lncm/lnd-rpc/v0.8.0/lnrpc/walletrpcb\x06proto3')
  ,
  dependencies=[lnrpc_dot_rpc__pb2.DESCRIPTOR,signrpc_dot_signer__pb2.DESCRIPTOR,])

_WITNESSTYPE = _descriptor.EnumDescriptor(
  name='WitnessType',
  full_name='walletrpc.WitnessType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_WITNESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMITMENT_TIME_LOCK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMITMENT_NO_DELAY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMITMENT_REVOKE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_OFFERED_REVOKE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_ACCEPTED_REVOKE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_OFFERED_TIMEOUT_SECOND_LEVEL', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_ACCEPTED_SUCCESS_SECOND_LEVEL', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_OFFERED_REMOTE_TIMEOUT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_ACCEPTED_REMOTE_SUCCESS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTLC_SECOND_LEVEL_REVOKE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITNESS_KEY_HASH', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NESTED_WITNESS_KEY_HASH', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1013,
  serialized_end=1399,
)
_sym_db.RegisterEnumDescriptor(_WITNESSTYPE)

WitnessType = enum_type_wrapper.EnumTypeWrapper(_WITNESSTYPE)
UNKNOWN_WITNESS = 0
COMMITMENT_TIME_LOCK = 1
COMMITMENT_NO_DELAY = 2
COMMITMENT_REVOKE = 3
HTLC_OFFERED_REVOKE = 4
HTLC_ACCEPTED_REVOKE = 5
HTLC_OFFERED_TIMEOUT_SECOND_LEVEL = 6
HTLC_ACCEPTED_SUCCESS_SECOND_LEVEL = 7
HTLC_OFFERED_REMOTE_TIMEOUT = 8
HTLC_ACCEPTED_REMOTE_SUCCESS = 9
HTLC_SECOND_LEVEL_REVOKE = 10
WITNESS_KEY_HASH = 11
NESTED_WITNESS_KEY_HASH = 12



_KEYREQ = _descriptor.Descriptor(
  name='KeyReq',
  full_name='walletrpc.KeyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_finger_print', full_name='walletrpc.KeyReq.key_finger_print', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_family', full_name='walletrpc.KeyReq.key_family', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=133,
)


_ADDRREQUEST = _descriptor.Descriptor(
  name='AddrRequest',
  full_name='walletrpc.AddrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=148,
)


_ADDRRESPONSE = _descriptor.Descriptor(
  name='AddrResponse',
  full_name='walletrpc.AddrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='walletrpc.AddrResponse.addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=178,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='walletrpc.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_hex', full_name='walletrpc.Transaction.tx_hex', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=209,
)


_PUBLISHRESPONSE = _descriptor.Descriptor(
  name='PublishResponse',
  full_name='walletrpc.PublishResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='publish_error', full_name='walletrpc.PublishResponse.publish_error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=251,
)


_SENDOUTPUTSREQUEST = _descriptor.Descriptor(
  name='SendOutputsRequest',
  full_name='walletrpc.SendOutputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sat_per_kw', full_name='walletrpc.SendOutputsRequest.sat_per_kw', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='walletrpc.SendOutputsRequest.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=326,
)


_SENDOUTPUTSRESPONSE = _descriptor.Descriptor(
  name='SendOutputsResponse',
  full_name='walletrpc.SendOutputsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_tx', full_name='walletrpc.SendOutputsResponse.raw_tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=365,
)


_ESTIMATEFEEREQUEST = _descriptor.Descriptor(
  name='EstimateFeeRequest',
  full_name='walletrpc.EstimateFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conf_target', full_name='walletrpc.EstimateFeeRequest.conf_target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=408,
)


_ESTIMATEFEERESPONSE = _descriptor.Descriptor(
  name='EstimateFeeResponse',
  full_name='walletrpc.EstimateFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sat_per_kw', full_name='walletrpc.EstimateFeeResponse.sat_per_kw', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=451,
)


_PENDINGSWEEP = _descriptor.Descriptor(
  name='PendingSweep',
  full_name='walletrpc.PendingSweep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outpoint', full_name='walletrpc.PendingSweep.outpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outpoint', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='witness_type', full_name='walletrpc.PendingSweep.witness_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='witness_type', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_sat', full_name='walletrpc.PendingSweep.amount_sat', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount_sat', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sat_per_byte', full_name='walletrpc.PendingSweep.sat_per_byte', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sat_per_byte', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcast_attempts', full_name='walletrpc.PendingSweep.broadcast_attempts', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='broadcast_attempts', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_broadcast_height', full_name='walletrpc.PendingSweep.next_broadcast_height', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='next_broadcast_height', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=743,
)


_PENDINGSWEEPSREQUEST = _descriptor.Descriptor(
  name='PendingSweepsRequest',
  full_name='walletrpc.PendingSweepsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=767,
)


_PENDINGSWEEPSRESPONSE = _descriptor.Descriptor(
  name='PendingSweepsResponse',
  full_name='walletrpc.PendingSweepsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pending_sweeps', full_name='walletrpc.PendingSweepsResponse.pending_sweeps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pending_sweeps', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=857,
)


_BUMPFEEREQUEST = _descriptor.Descriptor(
  name='BumpFeeRequest',
  full_name='walletrpc.BumpFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outpoint', full_name='walletrpc.BumpFeeRequest.outpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outpoint', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_conf', full_name='walletrpc.BumpFeeRequest.target_conf', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='target_conf', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sat_per_byte', full_name='walletrpc.BumpFeeRequest.sat_per_byte', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sat_per_byte', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=991,
)


_BUMPFEERESPONSE = _descriptor.Descriptor(
  name='BumpFeeResponse',
  full_name='walletrpc.BumpFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1010,
)

_SENDOUTPUTSREQUEST.fields_by_name['outputs'].message_type = signrpc_dot_signer__pb2._TXOUT
_PENDINGSWEEP.fields_by_name['outpoint'].message_type = lnrpc_dot_rpc__pb2._OUTPOINT
_PENDINGSWEEP.fields_by_name['witness_type'].enum_type = _WITNESSTYPE
_PENDINGSWEEPSRESPONSE.fields_by_name['pending_sweeps'].message_type = _PENDINGSWEEP
_BUMPFEEREQUEST.fields_by_name['outpoint'].message_type = lnrpc_dot_rpc__pb2._OUTPOINT
DESCRIPTOR.message_types_by_name['KeyReq'] = _KEYREQ
DESCRIPTOR.message_types_by_name['AddrRequest'] = _ADDRREQUEST
DESCRIPTOR.message_types_by_name['AddrResponse'] = _ADDRRESPONSE
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['PublishResponse'] = _PUBLISHRESPONSE
DESCRIPTOR.message_types_by_name['SendOutputsRequest'] = _SENDOUTPUTSREQUEST
DESCRIPTOR.message_types_by_name['SendOutputsResponse'] = _SENDOUTPUTSRESPONSE
DESCRIPTOR.message_types_by_name['EstimateFeeRequest'] = _ESTIMATEFEEREQUEST
DESCRIPTOR.message_types_by_name['EstimateFeeResponse'] = _ESTIMATEFEERESPONSE
DESCRIPTOR.message_types_by_name['PendingSweep'] = _PENDINGSWEEP
DESCRIPTOR.message_types_by_name['PendingSweepsRequest'] = _PENDINGSWEEPSREQUEST
DESCRIPTOR.message_types_by_name['PendingSweepsResponse'] = _PENDINGSWEEPSRESPONSE
DESCRIPTOR.message_types_by_name['BumpFeeRequest'] = _BUMPFEEREQUEST
DESCRIPTOR.message_types_by_name['BumpFeeResponse'] = _BUMPFEERESPONSE
DESCRIPTOR.enum_types_by_name['WitnessType'] = _WITNESSTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyReq = _reflection.GeneratedProtocolMessageType('KeyReq', (_message.Message,), dict(
  DESCRIPTOR = _KEYREQ,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.KeyReq)
  ))
_sym_db.RegisterMessage(KeyReq)

AddrRequest = _reflection.GeneratedProtocolMessageType('AddrRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDRREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.AddrRequest)
  ))
_sym_db.RegisterMessage(AddrRequest)

AddrResponse = _reflection.GeneratedProtocolMessageType('AddrResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.AddrResponse)
  ))
_sym_db.RegisterMessage(AddrResponse)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTION,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.Transaction)
  ))
_sym_db.RegisterMessage(Transaction)

PublishResponse = _reflection.GeneratedProtocolMessageType('PublishResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.PublishResponse)
  ))
_sym_db.RegisterMessage(PublishResponse)

SendOutputsRequest = _reflection.GeneratedProtocolMessageType('SendOutputsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDOUTPUTSREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.SendOutputsRequest)
  ))
_sym_db.RegisterMessage(SendOutputsRequest)

SendOutputsResponse = _reflection.GeneratedProtocolMessageType('SendOutputsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDOUTPUTSRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.SendOutputsResponse)
  ))
_sym_db.RegisterMessage(SendOutputsResponse)

EstimateFeeRequest = _reflection.GeneratedProtocolMessageType('EstimateFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _ESTIMATEFEEREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.EstimateFeeRequest)
  ))
_sym_db.RegisterMessage(EstimateFeeRequest)

EstimateFeeResponse = _reflection.GeneratedProtocolMessageType('EstimateFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _ESTIMATEFEERESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.EstimateFeeResponse)
  ))
_sym_db.RegisterMessage(EstimateFeeResponse)

PendingSweep = _reflection.GeneratedProtocolMessageType('PendingSweep', (_message.Message,), dict(
  DESCRIPTOR = _PENDINGSWEEP,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.PendingSweep)
  ))
_sym_db.RegisterMessage(PendingSweep)

PendingSweepsRequest = _reflection.GeneratedProtocolMessageType('PendingSweepsRequest', (_message.Message,), dict(
  DESCRIPTOR = _PENDINGSWEEPSREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.PendingSweepsRequest)
  ))
_sym_db.RegisterMessage(PendingSweepsRequest)

PendingSweepsResponse = _reflection.GeneratedProtocolMessageType('PendingSweepsResponse', (_message.Message,), dict(
  DESCRIPTOR = _PENDINGSWEEPSRESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.PendingSweepsResponse)
  ))
_sym_db.RegisterMessage(PendingSweepsResponse)

BumpFeeRequest = _reflection.GeneratedProtocolMessageType('BumpFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _BUMPFEEREQUEST,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.BumpFeeRequest)
  ))
_sym_db.RegisterMessage(BumpFeeRequest)

BumpFeeResponse = _reflection.GeneratedProtocolMessageType('BumpFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _BUMPFEERESPONSE,
  __module__ = 'walletrpc.walletkit_pb2'
  # @@protoc_insertion_point(class_scope:walletrpc.BumpFeeResponse)
  ))
_sym_db.RegisterMessage(BumpFeeResponse)


DESCRIPTOR._options = None

_WALLETKIT = _descriptor.ServiceDescriptor(
  name='WalletKit',
  full_name='walletrpc.WalletKit',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1402,
  serialized_end=1972,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeriveNextKey',
    full_name='walletrpc.WalletKit.DeriveNextKey',
    index=0,
    containing_service=None,
    input_type=_KEYREQ,
    output_type=signrpc_dot_signer__pb2._KEYDESCRIPTOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeriveKey',
    full_name='walletrpc.WalletKit.DeriveKey',
    index=1,
    containing_service=None,
    input_type=signrpc_dot_signer__pb2._KEYLOCATOR,
    output_type=signrpc_dot_signer__pb2._KEYDESCRIPTOR,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NextAddr',
    full_name='walletrpc.WalletKit.NextAddr',
    index=2,
    containing_service=None,
    input_type=_ADDRREQUEST,
    output_type=_ADDRRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PublishTransaction',
    full_name='walletrpc.WalletKit.PublishTransaction',
    index=3,
    containing_service=None,
    input_type=_TRANSACTION,
    output_type=_PUBLISHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendOutputs',
    full_name='walletrpc.WalletKit.SendOutputs',
    index=4,
    containing_service=None,
    input_type=_SENDOUTPUTSREQUEST,
    output_type=_SENDOUTPUTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateFee',
    full_name='walletrpc.WalletKit.EstimateFee',
    index=5,
    containing_service=None,
    input_type=_ESTIMATEFEEREQUEST,
    output_type=_ESTIMATEFEERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PendingSweeps',
    full_name='walletrpc.WalletKit.PendingSweeps',
    index=6,
    containing_service=None,
    input_type=_PENDINGSWEEPSREQUEST,
    output_type=_PENDINGSWEEPSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BumpFee',
    full_name='walletrpc.WalletKit.BumpFee',
    index=7,
    containing_service=None,
    input_type=_BUMPFEEREQUEST,
    output_type=_BUMPFEERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WALLETKIT)

DESCRIPTOR.services_by_name['WalletKit'] = _WALLETKIT

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from invoicesrpc import invoices_pb2 as invoicesrpc_dot_invoices__pb2
from lnrpc import rpc_pb2 as lnrpc_dot_rpc__pb2


class InvoicesStub(object):
  """Invoices is a service that can be used to create, accept, settle and cancel
  invoices.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SubscribeSingleInvoice = channel.unary_stream(
        '/invoicesrpc.Invoices/SubscribeSingleInvoice',
        request_serializer=invoicesrpc_dot_invoices__pb2.SubscribeSingleInvoiceRequest.SerializeToString,
        response_deserializer=lnrpc_dot_rpc__pb2.Invoice.FromString,
        )
    self.CancelInvoice = channel.unary_unary(
        '/invoicesrpc.Invoices/CancelInvoice',
        request_serializer=invoicesrpc_dot_invoices__pb2.CancelInvoiceMsg.SerializeToString,
        response_deserializer=invoicesrpc_dot_invoices__pb2.CancelInvoiceResp.FromString,
        )
    self.AddHoldInvoice = channel.unary_unary(
        '/invoicesrpc.Invoices/AddHoldInvoice',
        request_serializer=invoicesrpc_dot_invoices__pb2.AddHoldInvoiceRequest.SerializeToString,
        response_deserializer=invoicesrpc_dot_invoices__pb2.AddHoldInvoiceResp.FromString,
        )
    self.SettleInvoice = channel.unary_unary(
        '/invoicesrpc.Invoices/SettleInvoice',
        request_serializer=invoicesrpc_dot_invoices__pb2.SettleInvoiceMsg.SerializeToString,
        response_deserializer=invoicesrpc_dot_invoices__pb2.SettleInvoiceResp.FromString,
        )


class InvoicesServicer(object):
  """Invoices is a service that can be used to create, accept, settle and cancel
  invoices.
  """

  def SubscribeSingleInvoice(self, request, context):
    """*
    SubscribeSingleInvoice returns a uni-directional stream (server -> client)
    to notify the client of state transitions of the specified invoice.
    Initially the current invoice state is always sent out.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CancelInvoice(self, request, context):
    """*
    CancelInvoice cancels a currently open invoice. If the invoice is already 
    canceled, this call will succeed. If the invoice is already settled, it will
    fail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddHoldInvoice(self, request, context):
    """*
    AddHoldInvoice creates a hold invoice. It ties the invoice to the hash
    supplied in the request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SettleInvoice(self, request, context):
    """*
    SettleInvoice settles an accepted invoice. If the invoice is already
    settled, this call will succeed.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_InvoicesServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SubscribeSingleInvoice': grpc.unary_stream_rpc_method_handler(
          servicer.SubscribeSingleInvoice,
          request_deserializer=invoicesrpc_dot_invoices__pb2.SubscribeSingleInvoiceRequest.FromString,
          response_serializer=lnrpc_dot_rpc__pb2.Invoice.SerializeToString,
      ),
      'CancelInvoice': grpc.unary_unary_rpc_method_handler(
          servicer.CancelInvoice,
          request_deserializer=invoicesrpc_dot_invoices__pb2.CancelInvoiceMsg.FromString,
          response_serializer=invoicesrpc_dot_invoices__pb2.CancelInvoiceResp.SerializeToString,
      ),
      'AddHoldInvoice': grpc.unary_unary_rpc_method_handler(
          servicer.AddHoldInvoice,
          request_deserializer=invoicesrpc_dot_invoices__pb2.AddHoldInvoiceRequest.FromString,
          response_serializer=invoicesrpc_dot_invoices__pb2.AddHoldInvoiceResp.SerializeToString,
      ),
      'SettleInvoice': grpc.unary_unary_rpc_method_handler(
          servicer.SettleInvoice,
          request_deserializer=invoicesrpc_dot_invoices__pb2.SettleInvoiceMsg.FromString,
          response_serializer=invoicesrpc_dot_invoices__pb2.SettleInvoiceResp.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'invoicesrpc.Invoices', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
